@@ -642,7 +642,7 @@ public class PluginAppletViewer extends XEmbeddedFrame
             pav.dispose();
 
             // If panel is already disposed, return
-            if (pav.panel.applet == null) {
+            if (pav.panel.getApplet() == null) {
                 PluginDebug.debug(identifier, " panel inactive. Returning.");
                 return;
             }
@@ -718,8 +718,8 @@ public class PluginAppletViewer extends XEmbeddedFrame
                 panel.setSize(width, height);
                 panel.validate();
 
-                panel.applet.resize(width, height);
-                panel.applet.validate();
+                panel.getApplet().resize(width, height);
+                panel.getApplet().validate();
             }
         });
     }
@@ -829,14 +829,16 @@ public class PluginAppletViewer extends XEmbeddedFrame
                 PluginDebug.debug("getCachedImageRef() plugin codebase = ", codeBase);
 
                 String resourceName = originalURL.substring(codeBase.length());
-                JNLPClassLoader loader = (JNLPClassLoader) panel.getAppletClassLoader();
+                if (panel.getAppletClassLoader() instanceof JNLPClassLoader) {
+                    JNLPClassLoader loader = (JNLPClassLoader) panel.getAppletClassLoader();
 
-                URL localURL = null;
-                if (loader.resourceAvailableLocally(resourceName)) {
-                    url = loader.getResource(resourceName);
+                    URL localURL = null;
+                    if (loader.resourceAvailableLocally(resourceName)) {
+                        url = loader.getResource(resourceName);
+                    }
+
+                    url = localURL != null ? localURL : url;
                 }
-
-                url = localURL != null ? localURL : url;
             }
 
             PluginDebug.debug("getCachedImageRef() getting img from URL = ", url);
@@ -1421,8 +1423,8 @@ public class PluginAppletViewer extends XEmbeddedFrame
          * at the same time.
          */
         try {
-            ((AppletViewerPanel)panel).joinAppletThread();
-            ((AppletViewerPanel)panel).release();
+            ((AppletViewerPanelAccess)panel).joinAppletThread();
+            ((AppletViewerPanelAccess)panel).release();
         } catch (InterruptedException e) {
             return; // abort the reload
         }
@@ -1430,7 +1432,7 @@ public class PluginAppletViewer extends XEmbeddedFrame
         AccessController.doPrivileged(new PrivilegedAction<Void>() {
             @Override
             public Void run() {
-                ((AppletViewerPanel)panel).createAppletThread();
+                ((AppletViewerPanelAccess)panel).createAppletThread();
                 return null;
             }
         });
@@ -1500,7 +1502,9 @@ public class PluginAppletViewer extends XEmbeddedFrame
                 appletPanels.removeElement(p);
                 
                 // Mark classloader unusable
-                ((JNLPClassLoader) cl).decrementLoaderUseCount();
+                if (cl instanceof JNLPClassLoader) {
+                    ((JNLPClassLoader) cl).decrementLoaderUseCount();
+                }
 
                 try {
                     SwingUtilities.invokeAndWait(new Runnable() {
