@@ -50,6 +50,7 @@ import net.sourceforge.jnlp.ServerAccess;
 import net.sourceforge.jnlp.ServerLauncher;
 import net.sourceforge.jnlp.Version;
 import net.sourceforge.jnlp.runtime.JNLPRuntime;
+import net.sourceforge.jnlp.util.logging.OutputController;
 import net.sourceforge.jnlp.util.UrlUtils;
 import org.junit.AfterClass;
 import org.junit.Assert;
@@ -60,7 +61,7 @@ public class ResourceTrackerTest {
 
     public static ServerLauncher testServer;
     public static ServerLauncher testServerWithBrokenHead;
-    private static PrintStream backedUpStream;
+    private static PrintStream[] backedUpStream = new PrintStream[4];
     private static ByteArrayOutputStream currentErrorStream;
     private static final String nameStub1 = "itw-server";
     private static final String nameStub2 = "test-file";
@@ -80,7 +81,7 @@ public class ResourceTrackerTest {
             Assert.assertFalse("url " + i + " must be normalized (and so not equals) too normalized url " + i, u[i].equals(n[i]));
         }
     }
-    public static final int CHANGE_BORDER = 6;
+    public static final int CHANGE_BORDER = 8;
 
     public static URL[] getUrls() throws MalformedURLException {
         URL[] u = {
@@ -91,9 +92,9 @@ public class ResourceTrackerTest {
             new URL("http:///SpacesCanBeEverywhere1.jnlp"),
             new URL("file://localhost/home/jvanek/Desktop/icedtea-web/tests.build/jnlp_test_server/Spaces can be everywhere2.jnlp"),
             new URL("http://localhost:44321/testpage.jnlp?applicationID=25"),
-            /*changing*/
             new URL("http://localhost:44321/Spaces%20Can%20Be%20Everyw%2Fhere1.jnlp"),
             new URL("http://localhost/Spaces+Can+Be+Everywhere1.jnlp"),
+            /*changing*/
             new URL("http://localhost/SpacesC anBeEverywhere1.jnlp?a=5&b=10#df"),
             new URL("http:///oook.jnlp?a=5&b=ahoj šš dd#df"),
             new URL("http://localhost/Spacesěčšžšřýžčřú can !@^*(){}[].jnlp?a=5&ahoj šš dd#df"),
@@ -112,21 +113,47 @@ public class ResourceTrackerTest {
         return n;
 
     }
-  
+
     @BeforeClass
-    public static void redirectErr() {
-        if (backedUpStream == null) {
-            backedUpStream = System.err;
+    //keeping silent outputs from launched jvm
+    public static void redirectErr() throws IOException {
+        for (int i = 0; i < backedUpStream.length; i++) {
+            if (backedUpStream[i] == null) {
+                switch (i) {
+                    case 0:
+                        backedUpStream[i] = System.out;
+                        break;
+                    case 1:
+                        backedUpStream[i] = System.err;
+                        break;
+                    case 2:
+                        backedUpStream[i] = OutputController.getLogger().getOut();
+                        break;
+                    case 3:
+                        backedUpStream[i] = OutputController.getLogger().getErr();
+                        break;
+                }
+
+            }
+
         }
         currentErrorStream = new ByteArrayOutputStream();
+        System.setOut(new PrintStream(currentErrorStream));
         System.setErr(new PrintStream(currentErrorStream));
+        OutputController.getLogger().setOut(new PrintStream(currentErrorStream));
+        OutputController.getLogger().setErr(new PrintStream(currentErrorStream));
+
 
     }
 
     @AfterClass
-    public static void redirectErrBack() throws UnsupportedEncodingException {
+    public static void redirectErrBack() throws IOException {
         ServerAccess.logErrorReprint(currentErrorStream.toString("utf-8"));
-        System.setErr(backedUpStream);
+        System.setOut(backedUpStream[0]);
+        System.setErr(backedUpStream[1]);
+        OutputController.getLogger().setOut(backedUpStream[2]);
+        OutputController.getLogger().setErr(backedUpStream[3]);
+
 
     }
 
@@ -141,14 +168,18 @@ public class ResourceTrackerTest {
     }
 
     @BeforeClass
-    public static void startServer() throws IOException {
+    public static void startServer() throws Exception {
+        redirectErr();
         testServer = ServerAccess.getIndependentInstance(System.getProperty("java.io.tmpdir"), ServerAccess.findFreePort());
+        redirectErrBack();
     }
 
     @BeforeClass
-    public static void startServer2() throws IOException {
+    public static void startServer2() throws Exception {
+        redirectErr();
         testServerWithBrokenHead = ServerAccess.getIndependentInstance(System.getProperty("java.io.tmpdir"), ServerAccess.findFreePort());
         testServerWithBrokenHead.setSupportingHeadRequest(false);
+        redirectErrBack();
     }
 
     @AfterClass
@@ -162,7 +193,7 @@ public class ResourceTrackerTest {
     }
 
     @Test
-    public void getUrlResponseCodeTestWorkingHeadRequest() throws IOException {
+    public void getUrlResponseCodeTestWorkingHeadRequest() throws Exception {
         redirectErr();
         try {
             File f = File.createTempFile(nameStub1, nameStub2);
@@ -177,7 +208,7 @@ public class ResourceTrackerTest {
     }
 
     @Test
-    public void getUrlResponseCodeTestNotWorkingHeadRequest() throws IOException {
+    public void getUrlResponseCodeTestNotWorkingHeadRequest() throws Exception {
         redirectErr();
         try {
             File f = File.createTempFile(nameStub1, nameStub2);
@@ -192,7 +223,7 @@ public class ResourceTrackerTest {
     }
 
     @Test
-    public void getUrlResponseCodeTestGetRequestOnNotWorkingHeadRequest() throws IOException {
+    public void getUrlResponseCodeTestGetRequestOnNotWorkingHeadRequest() throws Exception {
         redirectErr();
         try {
             File f = File.createTempFile(nameStub1, nameStub2);
@@ -207,7 +238,7 @@ public class ResourceTrackerTest {
     }
 
     @Test
-    public void getUrlResponseCodeTestGetRequest() throws IOException {
+    public void getUrlResponseCodeTestGetRequest() throws Exception {
         redirectErr();
         try {
             File f = File.createTempFile(nameStub1, nameStub2);
@@ -222,7 +253,7 @@ public class ResourceTrackerTest {
     }
 
     @Test
-    public void getUrlResponseCodeTestWrongRequest() throws IOException {
+    public void getUrlResponseCodeTestWrongRequest() throws Exception {
         redirectErr();
         try {
             File f = File.createTempFile(nameStub1, nameStub2);
@@ -248,7 +279,7 @@ public class ResourceTrackerTest {
     }
 
     @Test
-    public void findBestUrltest() throws IOException {
+    public void findBestUrltest() throws Exception {
         redirectErr();
         try {
             File fileForServerWithHeader = File.createTempFile(nameStub1, nameStub2);
